@@ -35,6 +35,7 @@ public:
     typedef MatrixColumn<RTYPE> Column ;
     typedef SubMatrix<RTYPE> Sub ;
 
+    typedef StoragePolicy<Matrix> Storage ;
     typedef Vector<RTYPE, StoragePolicy> VECTOR ;
     typedef typename VECTOR::iterator iterator ;
     typedef typename VECTOR::const_iterator const_iterator ;
@@ -43,7 +44,7 @@ public:
     typedef typename VECTOR::Proxy Proxy ;
     typedef typename VECTOR::const_Proxy const_Proxy ;
 
-    Matrix() : VECTOR() {}
+    Matrix() : VECTOR(Dimension(0, 0)), nrows(0) {}
 
     Matrix(SEXP x) : VECTOR( r_cast<RTYPE>( x ) ), nrows( VECTOR::dims()[0] ) {}
 
@@ -52,7 +53,7 @@ public:
         VECTOR::init() ;
     }
     Matrix( const int& nrows_, const int& ncols) : VECTOR( Dimension( nrows_, ncols ) ),
-        nrows(nrows_)
+      nrows(nrows_)
     {}
 
     template <typename Iterator>
@@ -84,6 +85,10 @@ public:
     }
     Matrix& operator=( const SubMatrix<RTYPE>& ) ;
 
+    explicit Matrix( const no_init_matrix& obj) {
+        Storage::set__( Rf_allocMatrix( RTYPE, obj.nrow(), obj.ncol() ) );
+    }
+
     inline int ncol() const {
         return VECTOR::dims()[1];
     }
@@ -188,7 +193,15 @@ private:
         }
     }
 
-} ;
+};
+
+inline internal::DimNameProxy rownames(SEXP x) {
+    return internal::DimNameProxy(x, 0);
+}
+
+inline internal::DimNameProxy colnames(SEXP x) {
+    return internal::DimNameProxy(x, 1);
+}
 
 }
 
